/**
 * Licensed to Jasig under one or more contributor license
 * agreements. See the NOTICE file distributed with this work
 * for additional information regarding copyright ownership.
 * Jasig licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a
 * copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.jasig.portlet.weather.domain;

import java.io.Serializable;
import java.util.Collection;

/**
 * This class models general weather for a certain location including the
 * current weather and optional forecast weather.
 * 
 * @author Dustin Schultz
 * @version $Id: Weather.java 22379 2010-11-15 22:19:56Z edalquist $
 */
public class Weather implements Serializable {

	private static final long serialVersionUID = -3036893410887609714L;
	private Current currentWeather = null;
	private Location location = null;
	private Collection<Forecast> forecast = null;
	private String pressureUnit = null;
	private String temperatureUnit = null;
	private String windUnit = null;
	private String moreInformationLink = null; //for this weather object

	public Current getCurrentWeather() {
		return currentWeather;
	}

	public void setCurrentWeather(Current currentWeather) {
		this.currentWeather = currentWeather;
	}

	public Location getLocation() {
		return location;
	}

	public void setLocation(Location location) {
		this.location = location;
	}

	public Collection<Forecast> getForecast() {
		return forecast;
	}

	public void setForecast(Collection<Forecast> forecast) {
		this.forecast = forecast;
	}

	public String getPressureUnit() {
		return pressureUnit;
	}

	public void setPressureUnit(String pressureUnit) {
		this.pressureUnit = pressureUnit;
	}

	public String getTemperatureUnit() {
		return temperatureUnit;
	}

	public void setTemperatureUnit(String temperatureUnit) {
		this.temperatureUnit = temperatureUnit;
	}

	public String getWindUnit() {
		return windUnit;
	}

	public void setWindUnit(String windUnit) {
		this.windUnit = windUnit;
	}

	public String getMoreInformationLink() {
		return moreInformationLink;
	}

	public void setMoreInformationLink(String moreInformationLink) {
		this.moreInformationLink = moreInformationLink;
	}
}
